common

package
v0.0.0-...-764741f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2019 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetFirstGopath

func GetFirstGopath() (string, error)

func SplitCommaSepToMap

func SplitCommaSepToMap(commaSepString string) map[string]string

Splits a comma separated string consisting of key value pairs, e.g. "k1=v1,k2=v2", into a map

Types

This section is empty.

Directories

Path Synopsis
Library for establishing Thrift network connections for clients.
Library for establishing Thrift network connections for clients.
Wrappers for receivers from the common/stats package and setting up an HTTP server with endpoints to make the stats data accessible.
Wrappers for receivers from the common/stats package and setting up an HTTP server with endpoints to make the stats data accessible.
log
Library for common gRPC protobuf-related tools.
Library for common gRPC protobuf-related tools.
This package provides a set of minimal interfaces which both build on and are by default backed by go-metrics.
This package provides a set of minimal interfaces which both build on and are by default backed by go-metrics.
Utils for JSON and binary serialize/deserialize functions for Thrift structures
Utils for JSON and binary serialize/deserialize functions for Thrift structures

Jump to