server

package
v0.0.0-...-764741f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2019 License: Apache-2.0 Imports: 17 Imported by: 0

Documentation

Overview

Package server provides the implementation of the Scoot Worker Server, which implements the Worker API and starts the actual worker.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MakeServer

func MakeServer(
	handler worker.Worker,
	transport thrift.TServerTransport,
	transportFactory thrift.TTransportFactory,
	protocolFactory thrift.TProtocolFactory) thrift.TServer

Creates a Worker Server

func Module

func Module() ice.Module

Module returns a module that supports serving Thrift and HTTP

func NewHandler

func NewHandler(stat stats.StatsReceiver, run runner.Service) worker.Worker

Creates a new Handler which combines a runner.Service to do work and a StatsReceiver

func RunServer

func RunServer(
	bag *ice.MagicBag,
	schema jsonconfig.Schema,
	config []byte)

Starts the Server based on the MagicBag and config schema provided this method blocks until the server completes running or an exception occurs.

Types

type StatsCollectInterval

type StatsCollectInterval time.Duration

defining StatsCollectInterval type so it can be injected via ICE (avoid conflict with other injected integers)

Jump to