Documentation
¶
Overview ¶
Wrappers for receivers from the common/stats package and setting up an HTTP server with endpoints to make the stats data accessible.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MakeStatsReceiver ¶
func MakeStatsReceiver(scope StatScope) stats.StatsReceiver
Create a finagle-style stats receiver with a reasonable latch default, minutely.
Types ¶
type TwitterServer ¶
type TwitterServer struct {
Addr string
Stats stats.StatsReceiver
Handlers map[string]http.Handler
}
TODO(dbentley): rename to ObservableServer(?) A stats receiver that provides HTTP access for metric scraping with Twitter-style endpoints.
func NewTwitterServer ¶
func NewTwitterServer(addr Addr, stats stats.StatsReceiver, handlers map[string]http.Handler) *TwitterServer
Returns an http handler at 'addr'
func (*TwitterServer) Serve ¶
func (s *TwitterServer) Serve() error
Click to show internal directories.
Click to hide internal directories.