Documentation
¶
Index ¶
Constants ¶
const DefaultClientTimeout = time.Minute
const DefaultReadyFnBackoff = 5 * time.Second
How long to wait between runner status queries to determine [init] status.
const DefaultRunnerRetryInterval = time.Second
How long to sleep between runner req retries.
const DefaultRunnerRetryTimeout = 10 * time.Second
How long to keep retrying a runner req
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ClientTimeout ¶
type ClusterLocalConfig ¶
type ClusterLocalConfig struct {
Type string
}
Parameters for configuring a Scoot cluster that will have locally-run components.
func (*ClusterLocalConfig) Install ¶
func (c *ClusterLocalConfig) Install(bag *ice.MagicBag)
type ClusterMemoryConfig ¶
Parameters for configuring an in-memory Scoot cluster Count - number of in-memory workers
func (*ClusterMemoryConfig) Create ¶
func (c *ClusterMemoryConfig) Create() (*cluster.Cluster, error)
func (*ClusterMemoryConfig) Install ¶
func (c *ClusterMemoryConfig) Install(bag *ice.MagicBag)
type FileSagaLogConfig ¶
FileSagaLogConfig struct is used by goice to create a FileSagaLog instance of the SagaLog interface Directory specifies the name of the directory to store Sagalog files in.
func (*FileSagaLogConfig) Create ¶
func (c *FileSagaLogConfig) Create() (saga.SagaLog, error)
Creates an instance of the FileSagaLog
func (*FileSagaLogConfig) Install ¶
func (c *FileSagaLogConfig) Install(bag *ice.MagicBag)
Adds the FileSagaLogConfig Create function to the goice MagicBag
type InMemorySagaLogConfig ¶
InMemorySagaLog struct is used by goice to create an InMemory instance of the SagaLog interface.
func (*InMemorySagaLogConfig) Create ¶
func (c *InMemorySagaLogConfig) Create() saga.SagaLog
Creates an instance of an InMemorySagaLog
func (*InMemorySagaLogConfig) Install ¶
func (c *InMemorySagaLogConfig) Install(bag *ice.MagicBag)
Adds the InMemorySagaLog Create function to the goice MagicBag
type StatefulSchedulerConfig ¶
type StatefulSchedulerConfig struct {
Type string
MaxRetriesPerTask int
DebugMode bool
RecoverJobsOnStartup bool
DefaultTaskTimeout string
TaskTimeoutOverhead string
MaxRequestors int
MaxJobsPerRequestor int
Admins string
}
Parameters to configure the Stateful Scheduler MaxRetriesPerTask - the number of times to retry a failing task before
marking it as completed.
DebugMode - if true, starts the scheduler up but does not start
the update loop. Instead the loop must be advanced manually by calling step()
RecoverJobsOnStartup - if true, the scheduler recovers active sagas,
from the sagalog, and restarts them.
DefaultTaskTimeout - default timeout for tasks, human readable ex: "30m"
See scheduler.SchedulerConfig for comments on the remaining fields.
func (*StatefulSchedulerConfig) Create ¶
func (c *StatefulSchedulerConfig) Create() (scheduler.SchedulerConfig, error)
func (*StatefulSchedulerConfig) Install ¶
func (c *StatefulSchedulerConfig) Install(bag *ice.MagicBag)
type WorkersLocalConfig ¶
type WorkersLocalConfig struct {
Type string
}
Parameters for configuring locally started workers
func (*WorkersLocalConfig) Install ¶
func (c *WorkersLocalConfig) Install(bag *ice.MagicBag)
type WorkersThriftConfig ¶
type WorkersThriftConfig struct {
Type string
PollingPeriod string // will be parsed to a time.Duration
}
Parameters for configuring connections to remote (Thrift) workers.
func (*WorkersThriftConfig) Create ¶
func (c *WorkersThriftConfig) Create( tf thrift.TTransportFactory, pf thrift.TProtocolFactory, ct ClientTimeout) (func(cluster.Node) runner.Service, error)
func (*WorkersThriftConfig) Install ¶
func (c *WorkersThriftConfig) Install(bag *ice.MagicBag)