Documentation
¶
Overview ¶
Package temp makes hierarchical temporary directories it offers the same interface as ioutil, but recursive. The more you use this to create temporary directories, the fewer places we need to change when we want to relocate all our tempfiles.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type TempDir ¶
type TempDir struct {
Dir string
}
TempDir is a temporary directory, that may live under other temporary directories.
func NewTempDir ¶
Create a new TempDir in directory dir with prefix string.
func TempDirDefault ¶
TempDirDefault creates a TempDir rooted in the default temp dir
func TempDirHere ¶
TempDirHere creates a TempDir rooted in our current working directory Side effect: sets environment variable TMPDIR
func (*TempDir) FixedDir ¶
Create a new directory with a fixed name (this lets us structure our temp files)
Click to show internal directories.
Click to hide internal directories.