Documentation
¶
Overview ¶
Package server implements the Scoot Cloud API. For now, running the Cloud Server includes the Scheduler as well.
Index ¶
- func Defaults() (*ice.MagicBag, jsonconfig.Schema)
- func MakeServer(handler scoot.CloudScoot, transport thrift.TServerTransport, ...) thrift.TServer
- func NewHandler(scheduler scheduler.Scheduler, sc saga.SagaCoordinator, ...) scoot.CloudScoot
- func RunServer(bag *ice.MagicBag, schema jsonconfig.Schema, config []byte)
- type Handler
- func (h *Handler) GetSchedulerStatus() (*scoot.SchedulerStatus, error)
- func (h *Handler) GetStatus(jobId string) (*scoot.JobStatus, error)
- func (h *Handler) KillJob(jobId string) (*scoot.JobStatus, error)
- func (h *Handler) OfflineWorker(req *scoot.OfflineWorkerReq) error
- func (h *Handler) ReinstateWorker(req *scoot.ReinstateWorkerReq) error
- func (h *Handler) RunJob(def *scoot.JobDefinition) (*scoot.JobId, error)
- func (h *Handler) SetSchedulerStatus(maxNumTasks int32) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Defaults ¶
func Defaults() (*ice.MagicBag, jsonconfig.Schema)
Creates an MagicBag and a JsonSchema for this server and returns them
func MakeServer ¶
func MakeServer(handler scoot.CloudScoot, transport thrift.TServerTransport, transportFactory thrift.TTransportFactory, protocolFactory thrift.TProtocolFactory) thrift.TServer
Creates a Thrift server given a Handler and Thrift connection information
func NewHandler ¶
func NewHandler(scheduler scheduler.Scheduler, sc saga.SagaCoordinator, stat stats.StatsReceiver) scoot.CloudScoot
Creates and returns a new server Handler, which combines the scheduler, saga coordinator and stats receivers.
Types ¶
type Handler ¶
type Handler struct {
// contains filtered or unexported fields
}
Wrapping type that combines a scheduler, saga coordinator and stat receiver into a server
func (*Handler) GetSchedulerStatus ¶
func (h *Handler) GetSchedulerStatus() (*scoot.SchedulerStatus, error)
Implements GetSchedulerStatus Cloud Scoot API
func (*Handler) OfflineWorker ¶
func (h *Handler) OfflineWorker(req *scoot.OfflineWorkerReq) error
Implements OfflineWorker Cloud Scoot API
func (*Handler) ReinstateWorker ¶
func (h *Handler) ReinstateWorker(req *scoot.ReinstateWorkerReq) error
Implements ReinstateWorker Cloud Scoot API
func (*Handler) SetSchedulerStatus ¶
Implements SetSchedulerStatus Cloud Scoot API
Click to show internal directories.
Click to hide internal directories.