Documentation
¶
Index ¶
- func Module() ice.Module
- type BzFiler
- func (bf *BzFiler) Checkout(id string) (snapshot.Checkout, error)
- func (bf *BzFiler) CheckoutAt(id string, dir string) (snapshot.Checkout, error)
- func (bf *BzFiler) Ingest(path string) (string, error)
- func (bf *BzFiler) IngestMap(srcToDest map[string]string) (string, error)
- func (bf *BzFiler) Update() error
- func (bf *BzFiler) UpdateInterval() time.Duration
- type CheckoutNotExistError
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type BzFiler ¶
type BzFiler struct {
// Public resolver exposes selection of server host:port for underlying connections to cas
// NOTE: we may want to introduce a custom resolver that limits the number of underlying
// resolve calls if these are costly (i.e. make a network request) and we make a high number
// of CAS requests.
// GRPC package provides tools for making client connection contexts that support
// retry and backoff configuration, but we currently have to expose the resolver to
// an underlying tool that makes CAS requests on our behalf during Checkout and Ingest.
CASResolver dialer.Resolver
// contains filtered or unexported fields
}
Implements Snapshot interface (snapshot.Checkouter, snapshot.Ingester, and snapshot.Updater) Default tree implementation uses fs_util, a tool provided by pants at https://github.com/pantsbuild/binaries/tree/gh-pages/build-support/bin/fs_util which handles underlying implementation of bazel snapshot functionality
func (*BzFiler) CheckoutAt ¶
func (*BzFiler) UpdateInterval ¶
type CheckoutNotExistError ¶
type CheckoutNotExistError struct {
Err string
}
Type that indicates a Checkout operation failed because one or more input elements did not exist. This does not currently hold specific data, but could in the future include specific Digest information. This is limited by output from the underlying Filer -> BzTree implementation that uses the fs_util tool (materialize command).
func (*CheckoutNotExistError) Error ¶
func (c *CheckoutNotExistError) Error() string
Implements the Error interface