Documentation
¶
Overview ¶
Package server provides the implementation of the Scoot Worker Server, which implements the Worker API and starts the actual worker.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MakeServer ¶
func MakeServer( handler worker.Worker, transport thrift.TServerTransport, transportFactory thrift.TTransportFactory, protocolFactory thrift.TProtocolFactory) thrift.TServer
Creates a Worker Server
func NewHandler ¶
Creates a new Handler which combines a runner.Service to do work and a StatsReceiver
Types ¶
type StatsCollectInterval ¶
defining StatsCollectInterval type so it can be injected via ICE (avoid conflict with other injected integers)
Click to show internal directories.
Click to hide internal directories.